pub struct SignatoryKeySet {
pub id: Id,
pub unit: CurrencyUnit,
pub active: bool,
pub keys: Keys,
pub amounts: Vec<u64>,
pub input_fee_ppk: u64,
pub final_expiry: Option<u64>,
pub issuer_version: Option<IssuerVersion>,
}Expand description
SignatoryKeySet
This struct is used to represent a keyset and its info, pretty much all the information but the private key, that will never leave the signatory
Fields
id: IdThe keyset Id
unit: CurrencyUnitThe Currency Unit
active: boolWhether to set it as active or not
keys: KeysThe list of public keys
amounts: Vec<u64>Amounts supported by the keyset
input_fee_ppk: u64Input fee for the keyset (parts per thousand)
final_expiry: Option<u64>Final expiry of the keyset (unix timestamp in the future)
issuer_version: Option<IssuerVersion>Issuer Version